"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_1 = require("fs");
const meow_1 = __importDefault(require("meow"));
const chalk_1 = __importDefault(require("chalk"));
const debug_1 = __importDefault(require("debug"));
const generator_1 = require("./generator");
const config_1 = require("./config");
const debug = (0, debug_1.default)('api-docs-gen:cli');
async function main() {
    const flags = {
        output: {
            type: 'string',
            alias: 'o',
            isRequired: false
        },
        config: {
            type: 'string',
            alias: 'c',
            isRequired: false
        },
        generateStyle: {
            type: 'string',
            alias: 'g',
            default: "prefix" /* Prefix */
        },
        tsdocConfig: {
            type: 'string',
            alias: 't',
            default: ''
        }
    };
    const cli = (0, meow_1.default)(`
    Usage
      $ api-docs-gen <package1.api.json> <package2.api.json> ...

    Options
      --config, -c              configration file
      --output, -o              output dierectory that is markdown contents
      --generateStyle, -g       document generating style, default 'prefix'
                                'prefix': be able to separated with each package name
                                'noprefix': not separated with each package name
                                'directory': be able to separated with each package directory
      --tsdocConfig, -t         tsdoc configration file

    Examples
      $ api-docs-gen package1.api.json
      $ api-docs-gen package1.api.json --output ./docs
      $ api-docs-gen package1.api.json --config docsgen.config.js
      $ api-docs-gen package1.api.json package2.api.json --generateStyle directory
      $ api-docs-gen package1.api.json --tsdocConfig ./tsdoc.json
  `, 
    // @ts-ignore
    {
        flags
    });
    debug('flags', flags);
    // check input
    const input = cli.input;
    if (!input.length) {
        cli.showHelp(1);
    }
    debug('input', input);
    // resolve output
    const output = cli.flags.output != null ? path_1.default.resolve(cli.flags.output) : process.cwd();
    debug(`output`, output);
    // mkdir directory, if not exist
    try {
        await fs_1.promises.mkdir(output, { recursive: true });
    }
    catch (e) {
        console.error(chalk_1.default.red(`[api-docs-gen] make output directory error: ${e.message}`));
        process.exit(1);
    }
    // config
    let config = config_1.DefaultConfig;
    try {
        config = (0, config_1.resolveConfig)(cli.flags.config);
    }
    catch (e) {
        console.error(chalk_1.default.red(`[api-docs-gen] ${e.message}`));
        process.exit(1);
    }
    debug(`config`, config);
    // generate style
    const genStyleFlag = cli.flags['generateStyle'];
    const genStyle = [
        "prefix" /* Prefix */,
        "noprefix" /* NoPrefix */,
        "directory" /* Directory */
    ].includes(genStyleFlag)
        ? genStyleFlag
        : "prefix" /* Prefix */;
    debug('packageDocsStyle', genStyleFlag, genStyle);
    // tsdoc configratio
    const tsdocConfig = cli.flags['tsdocConfig'];
    debug('tsdocConfig', tsdocConfig);
    // run
    try {
        ;
        (async () => {
            await (0, generator_1.generate)(input, output, {
                style: genStyle,
                config,
                tsdocConfigPath: tsdocConfig
                    ? path_1.default.resolve(process.cwd(), tsdocConfig)
                    : undefined,
                errorOnTSDocConfig: (error) => {
                    console.log(chalk_1.default.yellow(`⚠️ Error on TSDoc configration: ${error}`));
                },
                done: (pkgname, filepath) => {
                    console.log(chalk_1.default.green(`📦 ${pkgname}: 📝 save ${filepath}`));
                }
            });
        })();
    }
    catch (e) {
        console.error(chalk_1.default.red(`[api-docs-gen] ${e.message}`));
        process.exit(1);
    }
}
/*
process.on('uncaughtException', err => {
  console.error(chalk.red(`[api-docs-gen] Uncaught exception: ${err}\n`))
  process.exit(1)
})

process.on('unhandledRejection', (reason, p) => {
  console.error(
    chalk.red(`[api-docs-gen] Unhandled rejection at: ${p}, reason: ${reason}`)
  )
  process.exit(1)
})
*/
main();
