"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeFile = exports.mkdir = exports.getSafePathFromDisplayName = exports.escapeTextForTable = exports.escapeText = void 0;
const fs_1 = require("fs");
/**
 * Escape text for markdown
 *
 * @param text - the target text
 *
 * @returns escaped text
 *
 * @public
 */
function escapeText(text) {
    return text
        .replace(/\\/g, '\\\\') // first replace the escape character
        .replace(/[*#[\]_|`~]/g, (x) => '\\' + x) // then escape any special characters
        .replace(/---/g, '\\-\\-\\-') // hyphens only if it's 3 or more
        .replace(/&/g, '&amp;')
        .replace(/</g, '&lt;')
        .replace(/>/g, '&gt;');
}
exports.escapeText = escapeText;
/**
 * Escape text for markdown table
 *
 * @param text - the target text
 *
 * @returns escaped text
 *
 * @public
 */
function escapeTextForTable(text) {
    return text
        .replace(/&/g, '&amp;')
        .replace(/"/g, '&quot;')
        .replace(/</g, '&lt;')
        .replace(/>/g, '&gt;')
        .replace(/\|/g, '&#124;');
}
exports.escapeTextForTable = escapeTextForTable;
const RE_BAD_PATH_CHARS = /[^a-z0-9_\-\.]/gi;
/**
 * Get safe path from display name of {@link https://rushstack.io/pages/api/api-extractor-model.apiitem/ | ApiItem}
 *
 * @param name - the target displayname
 *
 * @returns safe path
 *
 * @public
 */
function getSafePathFromDisplayName(name) {
    return name.replace(RE_BAD_PATH_CHARS, '_').toLowerCase();
}
exports.getSafePathFromDisplayName = getSafePathFromDisplayName;
async function mkdir(path) {
    await fs_1.promises.mkdir(path, { recursive: true });
}
exports.mkdir = mkdir;
async function writeFile(path, data) {
    await fs_1.promises.writeFile(path, data, 'utf-8');
}
exports.writeFile = writeFile;
